@@ -40,8 +40,8 @@ def fetch_relational_data(
                 table_name=table_name,
                 column_name=column_name,
                 compair_operator=compair_operator,
-                column_values='({})'.format(
-                    ', '.join([str(val) for val in column_values])) if compair_operator == 'IN' else column_values,
+                column_values="({})".format(
+                    "', '".join([str(val) for val in column_values])) if compair_operator == 'IN' else column_values,
             )
             relational_data_result = sql(query)
 
