@@ -3,6 +3,11 @@ from wedeliver_core import WeDeliverCore
 
 
 def sql(query):
+    """
+
+    :param query:
+    :return:
+    """
     app = WeDeliverCore.get_app()
     db = app.extensions['sqlalchemy'].db
 
@@ -18,3 +23,14 @@ def sql(query):
         result_list.append(temp)
 
     return result_list
+
+
+def no_result_sql(query):
+    """
+
+    :param query:
+    """
+    app = WeDeliverCore.get_app()
+    db = app.extensions['sqlalchemy'].db
+    app.logger.debug(query)
+    db.engine.execute(text(query))
